@@ -8,6 +8,10 @@ try:
 except _metadata.PackageNotFoundError:  # pragma: no-cover
     # If the package is not installed such that it has distribution metadata
     # fallback to loading the version from the pyproject.toml file.
-    __version__ = _toml.loads(
+    _package_metadata = _toml.loads(
         _pathlib.Path(__file__).parent.parent.joinpath("pyproject.toml").read_text()
-    )["tool"]["poetry"]["version"]
+    )
+    try:
+        __version__ = _package_metadata["tool"]["poetry"]["version"]
+    except KeyError:
+        __version__ = _package_metadata["project"]["version"]
